@@ -9,7 +9,6 @@ Usage::
     data: PredictedItemTypeDef = {...}
     ```
 """
-import sys
 from typing import List
 
 if sys.version_info >= (3, 8):
@@ -30,10 +29,12 @@ PredictedItemTypeDef = TypedDict(
 
 GetPersonalizedRankingResponseTypeDef = TypedDict(
     "GetPersonalizedRankingResponseTypeDef",
-    {"personalizedRanking": List["PredictedItemTypeDef"]},
+    {"personalizedRanking": List["PredictedItemTypeDef"], "recommendationId": str},
     total=False,
 )
 
 GetRecommendationsResponseTypeDef = TypedDict(
-    "GetRecommendationsResponseTypeDef", {"itemList": List["PredictedItemTypeDef"]}, total=False
+    "GetRecommendationsResponseTypeDef",
+    {"itemList": List["PredictedItemTypeDef"], "recommendationId": str},
+    total=False,
 )
